@@ -1,9 +1,9 @@
 {-# LANGUAGE CPP #-}
 
-import Criterion.Main
 import Data.Binary
 import Data.Binary.Get
 import Data.Binary.Put
+import Gauge.Main
 
 import qualified Data.ByteString.Lazy     as BS
 import qualified Data.Vector.Unboxed as U
@@ -18,11 +18,6 @@ instance NFData BS.ByteString where
     rnf (BS.Chunk _ b) = rnf b
 #endif
 
--- We take care to avoid using the @Binary@ instances here to avoid issues with
--- overlapping instances as the install plan will involve two different versions
--- of k@vector-binary-instances@ (as @Criterion@ transitively depends upon
--- @vector-binary-instances@). See #7 for details.
-
 vec1,vec2,vec3,vec4,vec5 :: U.Vector Int
 vec1 = U.enumFromN 0 3
 vec2 = U.enumFromN 0 30
